c       +++++++++++++++++++++++++++++++++++++++++++++++++++++++++
c       +                                                       +
c       +  This DECK defines the basic functions of             +
c       +  plotting. The results will be a postscript file.     +
c       +                                                       +
c       +  The program is written by Jess U Jorgensen (DMI).    +
c       +  More fonts are included; line thickness are modified +
c       +  and some small modifications are made by Hans X.-Y.  +
c       +  Huang (DMI).                                         +
c       +                                                       +
c       +  The program has been tested with MetgraF, XYPLOT on  +
c       +  CONVEX, SUN, SGI, IBM, DEC, ...                      +
c       +                                                       +
c       +  Please send your comments and modifications to:      +
c       +          juj@dmicvx.dmi.min.dk                        +
c       +          xyh@dmicvx.dmi.min.dk                        +
c       +                                                       +
c       +++++++++++++++++++++++++++++++++++++++++++++++++++++++++
c
c  This plotex driver has a render build in, which means that all 
c  graphics call are stored in memory in the render mode and finally
c  processed in RENPTX. Then the render can use postscript or a
c  screen driver. Communication with the render is done with the
c  namelist namplo.
c
c The graphics mode is controlled by the variables in common block COMPOST
c
c  all combinations are valid.
c
c                     1         2      3       4      5       6
c
c                    post-   driver   post-  ps &   render render
c variable\output   script   depend. script  driver driver ps & driver
c lpost               f       f        t      t      t        t
c lgs                 f       t        f      t      f        t
c lsave               f       f        f      f      t        t
c
c  The default output device is to write out in a simple
c  postscript file (3). 
c
c               
c if you have a plotex-driver allready - rename your subroutines like
c
c           newpex -> snewpex (screen newpex)
c           symbex -> ssymbex (screen symbol)
c
c and use the define variable HAS_DRIVER and use (2)
c
c In order to use rendering your driver must support a larger frambuffer
c than your device actually is. If your driver does not support it
c you need to put max(min(xmax,f),xmin) on the x and y coordinates. 
c This feature is not build in the render routines since most drivers
c support it already.
c
c  color table 01      black
c              02 - 16 normal spekter red-yellow-green-blue
c              17 - 23 yellow-green
c              24 - 29 sharp contrast
c              30      white
c
c 5 different shading styles are supported:
c
c             fill
c             thin and thick horizontal and vertical hashing. 
c
c 6 different linestyles are supported.
c
c             full
c             5 diffent dashed dot combinations
c
c a logical variable "Color" in the top of the postscript file is 
c true by default. The default value will produce the plot exactly as
c produced. Turning it false, lines will change style in black rather than
c color. The color table will be change to gray scale. This is usefull when
c optimizing the output for screen and monochome printer.
c 
c 
c It is posible to make a compact form of the output postscript file
c due to the structure of the postscript file. This procedure will reduce
c the file size significantly compared to what compress and gzip can do. 
c This feature will be supported if needed.
c
c
c
c
      subroutine plotex(a,b)
      character*(*) a,b
      character*(*) symb,font
      real xc(*),yc(*)
#include "compost.inc"
#include "plotcom.inc"
      if ( lsave ) then
      call xplotex(a,b)
      else
      call pplotex(a,b)
      endif
      return
      entry symbex(x,y,hgt,symb,ang,nsymb)
c
      if ( lsave ) then
      call xsymbex(x,y,hgt,symb,ang,nsymb)
      else
      call psymbex(x,y,hgt,symb,ang,nsymb)
      endif
      return
      entry pfill(xc,yc,nc,ncol,nshade)
c
      if ( lsave ) then
      call xpfill(xc,yc,nc,ncol,nshade)
      else
      call ppfill(xc,yc,nc,ncol,nshade)
      endif
      return
      entry newfon(font)
c
      if ( lsave ) then
      call xnewfon(font)
      else
      call pnewfon(font)
      endif
      return
      entry newpex(ithick,icolor)
c
      if ( lsave ) then
      call xnewpex(ithick,icolor)
      else
      call pnewpex(ithick,icolor)
      endif
      return
      entry vectex(x1,y1,x2,y2,jtyp)
c
      if ( lsave ) then
      call xvectex(x1,y1,x2,y2,jtyp)
      else
      call pvectex(x1,y1,x2,y2,jtyp)
      endif
      return
      entry linex(xc,yc,n,jtyp)
c
      if ( lsave ) then
      call xlinex(xc,yc,n,jtyp)
      else
      call plinex(xc,yc,n,jtyp)
      endif
      return
      entry endex
c
      if ( lsave ) then
      call xendex
      else
      call pendex
      endif
      end
