
c---------------------------------------------------------------------------
c    type:        subroutine iniobs
c    func:        sets up the geometry according to map projection.
c    system:      metgraf
c    author:      nils gustafsson mf
c    date:
c
c    call iniobs(xmin,xmax,ymin,ymax)
c
c    where
c
c    variable	 dim   type (i/o/w)	 content
c    --------	 ---   ---- ------    -------
c    xmin              r     (i)  minimum paper/screen x -coord to be plotted
c    xmax              r     (i)  maximum    -"-             -"-
c    ymin              r     (i)  minimum    -"-       y -   -"-
c    ymax              r     (i)  maximum    -"-             -"-
c
c    entry points:       xyobs(latobs,lonobs,xobs,yobs,tilt)
c    called subroutines: grerik, kulan
c
c---------------------------------------------------------------------------
      subroutine iniobs(xmin,xmax,ymin,ymax)
      real xmin,xmax,ymin,ymax
      integer latobs,lonobs
      real xobs,yobs,tilt
C
C save is necessary (at least) on ibm590
C
      save
      parameter(pi=3.14159265358979323846,zradi=0.01745329251994329576)
c
#include "comrep.inc"
#include "comdef.inc"
#include "comlog.inc"

      eps = 5.e-4
      epspol = pi/2. - eps
      rearth = 6.371e+06
c
c------------------------------------------------------------------------------
c
c         map projection is regular lat/long
c
      if( maprep.eq.0 ) then
c
         prolat = 90.
         alatnp = prolat
         zfac = zradi*rearth/(scale*1.e+6)*100.0
         zyor =  latmid*zfac - 0.5*dymap
         zxor =  lonmid*zfac - 0.5*dxmap
         xmin = 1.e-5
         ymin = 1.e-5
         xmax = dxmap + 2.e-5
         ymax = dymap + 2.e-5
         return
c
c------------------------------------------------------------------------------
c
c         map projection is mercator
c
      else if( maprep.eq.01 ) then
c
         zprola = prolat*zradi
         zmult = rearth*cos(zprola)/(scale*1.e+6)*100.
         zlatm  = latmid*zradi
         zlonm  = lonmid*zradi
c        if( zlonm.gt.pi ) zlonm = zlonm - 2.*pi
         zxor = zmult*zlonm - 0.5*dxmap
         zyor = zmult*alog( (1.+sin(zlatm))/cos(zlatm) ) - 0.5*dymap
         xmin = 1.e-5
         ymin = 1.e-5
         xmax = dxmap + 2.e-5
         ymax = dymap + 2.e-5
         write(6,*) 'zmult,zxor,zyor:',zmult,zxor,zyor
         return
c
c------------------------------------------------------------------------------
c
c         map projection is polarstereographic
c
      else if( maprep.eq.05 ) then
c
         zprola = prolat*zradi
         zprolo = prolon*zradi
         if( prolat.ge.0. ) then
            zrlen = ( 1. + sin(zprola))*rearth/(scale*1.e+6)*100.
         else
            zrlen = ( 1. - sin(zprola))*rearth/(scale*1.e+6)*100.
         endif
         zlatm  = latmid*zradi
         zlonm  = lonmid*zradi - zprolo
         if( prolat.ge.0. ) then
            zrmid = zrlen*cos(zlatm)/(1.+sin(zlatm))
         else
            zrmid = zrlen*cos(zlatm)/(1.-sin(zlatm))
            zlonm = - zlonm
         endif
         zyor = - zrmid*cos(zlonm) - 0.5*dymap
         zxor =   zrmid*sin(zlonm) - 0.5*dxmap
         xmin = 1.e-5
         ymin = 1.e-5
         xmax = dxmap + 2.e-5
         ymax = dymap + 2.e-5
         return
c
c------------------------------------------------------------------------------
c
c         map projection is kulan
c
      else if( maprep.eq.30 ) then
c
         zmult = rearth/(scale*1.e+6)*100.
         xmin = 1.e-5
         ymin = 1.e-5
         xmax = dxmap + 2.e-5
         ymax = dymap + 2.e-5
         return
c
c------------------------------------------------------------------------------
c
c         map projection is lat/long with shifted pole
c
      else if( maprep.eq.10 ) then
c
         alatnp = prolat
         zfac = zradi*rearth/(scale*1.e+6)*100.0
         zlatm = fiprim(latmid,lonmid,prolat)
         zlonm = alampr(latmid,lonmid,prolat)
         zyor =  zlatm*zfac - 0.5*dymap
         zxor =  zlonm*zfac - 0.5*dxmap
         xmin = 1.e-5
         ymin = 1.e-5
         xmax = dxmap + 2.e-5
         ymax = dymap + 2.e-5
         return
c
c------------------------------------------------------------------------------
c
c         map projection is rikets koordinater
c
      else if( maprep.eq.98 ) then
c
         zfac = 1./(scale*1.e+6)*100.0
         call grerik(latmid,lonmid,zymid,zxmid)
         zyor =  zymid*zfac - 0.5*dymap
         zxor =  zxmid*zfac - 0.5*dxmap
         xmin = 1.e-5
         ymin = 1.e-5
         xmax = dxmap + 2.e-5
         ymax = dymap + 2.e-5
         return
c
c------------------------------------------------------------------------------
c
      else
         write(lulog,*)' observation plotting in projection ',maprep
         write(lulog,*)'  not yet implemented!!!!!!!'
         stop
      endif
c
c******************************************************************************
c
      entry xyobs(latobs,lonobs,xobs,yobs,tilt)
c
c------------------------------------------------------------------------------
c
c         map projection is regular lat/long
c
      if( maprep.eq.0 ) then
c
         xobs = float(lonobs)*0.001*zfac - zxor
         yobs = float(latobs)*0.001*zfac - zyor
         tilt = 0.
         return
c
c------------------------------------------------------------------------------
c
c         map projection is mercator
c
      else if( maprep.eq.01 ) then
c
         zlat   = float(latobs)*0.001*zradi
         zlon   = float(lonobs)*0.001*zradi
c        if( zlon.gt.pi ) zlon = zlon - 2.*pi
         if( zlon.gt.0 .and. (lonmid.eq.-160.0 .or. lonmid.eq.-150.0) )
     +       zlon = zlon - 2.*pi
         xobs = zmult*zlon                             - zxor
         yobs = zmult*alog( (1.+sin(zlat))/cos(zlat) ) - zyor
         tilt = 0.
         return
c
c------------------------------------------------------------------------------
c
c         map projection is polarstereographic
c
      else if( maprep.eq.05 ) then
c
         zlat = float(latobs)*0.001*zradi
         zlon = float(lonobs)*0.001*zradi - zprolo
         if( prolat.ge.0. ) then
            zr = zrlen*cos(zlat)/(1.+sin(zlat))
         else
            zr = zrlen*cos(zlat)/(1.-sin(zlat))
            zlon = - zlon
         endif
         yobs = - zr*cos(zlon) - zyor
         xobs =   zr*sin(zlon) - zxor
         tilt = zlon/zradi
         return
c
c------------------------------------------------------------------------------
c
c         map projection is kulan
c
      else if( maprep.eq.30 ) then
c
         zlong = float(lonobs)*0.001
         zlatg = float(latobs)*0.001
         call kulan(zlatg,zlong,x,y,latmid,lonmid,strch)
         xobs = zmult*x + dxmap*0.5
         yobs = zmult*y + dymap*0.5
c
         zlatg = float(latobs+500)*0.001
         call kulan(zlatg,zlong,x,y,latmid,lonmid,strch)
         xnor = zmult*x + dxmap*0.5
         ynor = zmult*y + dymap*0.5
         tilt = atan2(xobs-xnor,ynor-yobs)/zradi
c
         return
c
c------------------------------------------------------------------------------
c
c         map projection is lat/long with shifted pole
c
      else if( maprep.eq.10 ) then
c
         zlong = float(lonobs)*0.001
         zlatg = float(latobs)*0.001
         zlatm = fiprim(zlatg,zlong,prolat)
         zlonm = alampr(zlatg,zlong,prolat)
         xobs  = zlonm*zfac - zxor
         yobs  = zlatm*zfac - zyor
c
         zlatg = float(latobs+500)*0.001
         zlatm = fiprim(zlatg,zlong,prolat)
         zlonm = alampr(zlatg,zlong,prolat)
         xnor   = zlonm*zfac - zxor
         ynor   = zlatm*zfac - zyor
         tilt = atan2(xobs-xnor,ynor-yobs)/zradi
c
         return
c
c------------------------------------------------------------------------------
c
c         map projection is rikets koordinater
c
      else if( maprep.eq.98 ) then
c
         zlong = float(lonobs)*0.001
         zlatg = float(latobs)*0.001
         call grerik(zlatg,zlong,zy,zx)
         xobs = zx*zfac - zxor
         yobs = zy*zfac - zyor
c
         zlatg = float(latobs+500)*0.001
         call grerik(zlatg,zlong,zy,zx)
         xnor = zx*zfac - zxor
         ynor = zy*zfac - zyor
         tilt = atan2(xobs-xnor,ynor-yobs)/zradi
c
         return
c
c------------------------------------------------------------------------------
c
      else
         write(lulog,*)' observation plotting in projection ',maprep
         write(lulog,*)'  not yet implemented!!!!!!!'
         stop
      endif
c
      end

